yakumo.neutron.v2.lbaas.pool

Package yakumo :: Package neutron :: Package v2 :: Package lbaas :: Module pool |
[hide private]
[frames] | no frames]

# Module pool

source code

Resource class and its manager for LBaaS Pools in Networking V2 API

Classes | [hide private]
| Resource Resource class for LBaaS Pools in Networking V2 API
| Manager Manager class for LBaaS Pools in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.lbaas``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('lb_algorithm', 'lb_algorithm', map
      per.Noop), ('protocol', 'protocol', mapper.Noop), ('listeners', 'liste
      ners', mapper.List(mapper.Resource('neutron.lbaas.listeners'))), ('mem
      bers', 'members', mapper.List(mapper.Resource('neutron.lbaas.member'))
      ), ('project', 'tenant_id', mapper.Resource('project')), ('healthmonit
      or', 'healthmonitor_id', mapper.Resource('neutron.lbaas.health_monitor
      ')), ('is_enabled', 'admin_state_up', mapper.Noop),]